@@ -356,21 +356,24 @@ class DataPlotterCallback(Callback):
         inputs_real = []
         outputs_real = []
         outputs_fake = []
-        
+                
+        dtype = self.trainer.network_dtype
+
         for input_real, output_real in self.inputs_outputs_real:
             inputs_real.append(input_real)
             outputs_real.append(output_real)
-        
-        dtype = self.trainer.network_dtype
 
-        inputs_real = self.trainer.to_tensor(inputs_real, dtype=dtype)
-        outputs_real = self.trainer.to_tensor(outputs_real, dtype=dtype)
-        
-        outputs_fake = self.trainer.network(inputs_real)
+            input_real = self.trainer.to_tensor([input_real], dtype=dtype)
+            
+            output_fake = self.trainer.network(input_real)
+            output_fake = output_fake[0]
+            output_fake = self.trainer.to_numpy(output_fake)
+            
+            outputs_fake.append(output_fake)
 
-        inputs_real = self.trainer.to_numpy(inputs_real)
-        outputs_real = self.trainer.to_numpy(outputs_real)
-        outputs_fake = self.trainer.to_numpy(outputs_fake)
+        inputs_real = np.asarray(inputs_real)
+        outputs_real = np.asarray(outputs_real)
+        outputs_fake = np.asarray(outputs_fake)
 
         for key in logs:
             if key not in self.epoch_logs.keys():
